# Shimpy

![PyPI](https://img.shields.io/pypi/v/shimpy)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/shimpy)

![PyPI - Downloads](https://img.shields.io/pypi/dm/shimpy)

Sample CLI Tool to interact with Shimmer Network using [iota-sdk](https://pypi.org/project/iota-sdk/).

## Install

### Using pip

`pip install shimpy`

### Using poetry

`poetry add shimpy`

## Usage

`shimpy --help`

## Commands

- info : Get Info about Node
- account
  - new: Generate new account
  - balance: Get balance by account alias
  - list: List all accounts
- address
  - new: Generate new address for account
  - list: List all addresses in the account
- nft
  - mint: Mint new NFT
  - send: Send NFT to an address
- send: Send SMR to an address

### Contributions Welcome

#### Under Development
